@@ -47,6 +47,13 @@ G_BEGIN_DECLS
 typedef struct _GstMixer GstMixer;
 typedef struct _GstMixerClass GstMixerClass;
 
+/**
+ * GstMixerType:
+ * @GST_MIXER_HARDWARE: mixing is implemented with dedicated hardware.
+ * @GST_MIXER_SOFTWARE: mixing is implemented via software processing.
+ *
+ * Mixer classification.
+ */
 typedef enum
 {
   GST_MIXER_HARDWARE,
@@ -197,7 +204,7 @@ void            gst_mixer_volume_changed (GstMixer      *mixer,
                                           gint          *volumes);
 void            gst_mixer_option_changed (GstMixer      *mixer,
                                           GstMixerOptions *opts,
-                                          gchar         *value);
+                                          const gchar   *value);
 
 void            gst_mixer_mixer_changed   (GstMixer        *mixer);
 
